@@ -260,14 +260,6 @@ class Client:
         This allows you to check requests the library is using. For more information, check the
         `aiohttp documentation <https://docs.aiohttp.org/en/stable/client_advanced.html#client-tracing>`_.
 
-        .. versionadded:: 2.0
-    max_ratelimit_timeout: Optional[:class:`float`]
-        The maximum number of seconds to wait when a non-global rate limit is encountered.
-        If a request requires sleeping for more than the seconds passed in, then
-        :exc:`~discord.RateLimited` will be raised. By default, there is no timeout limit.
-        In order to prevent misuse and unnecessary bans, the minimum value this can be
-        set to is ``30.0`` seconds.
-
         .. versionadded:: 2.0
 
     Attributes
@@ -288,14 +280,12 @@ class Client:
         proxy_auth: Optional[aiohttp.BasicAuth] = options.pop('proxy_auth', None)
         unsync_clock: bool = options.pop('assume_unsync_clock', True)
         http_trace: Optional[aiohttp.TraceConfig] = options.pop('http_trace', None)
-        max_ratelimit_timeout: Optional[float] = options.pop('max_ratelimit_timeout', None)
         self.http: HTTPClient = HTTPClient(
             self.loop,
             proxy=proxy,
             proxy_auth=proxy_auth,
             unsync_clock=unsync_clock,
             http_trace=http_trace,
-            max_ratelimit_timeout=max_ratelimit_timeout,
         )
 
         self._handlers: Dict[str, Callable[..., None]] = {
@@ -370,18 +360,18 @@ class Client:
         return self._connection.user
 
     @property
-    def guilds(self) -> Sequence[Guild]:
-        """Sequence[:class:`.Guild`]: The guilds that the connected client is a member of."""
+    def guilds(self) -> List[Guild]:
+        """List[:class:`.Guild`]: The guilds that the connected client is a member of."""
         return self._connection.guilds
 
     @property
-    def emojis(self) -> Sequence[Emoji]:
-        """Sequence[:class:`.Emoji`]: The emojis that the connected client has."""
+    def emojis(self) -> List[Emoji]:
+        """List[:class:`.Emoji`]: The emojis that the connected client has."""
         return self._connection.emojis
 
     @property
-    def stickers(self) -> Sequence[GuildSticker]:
-        """Sequence[:class:`.GuildSticker`]: The stickers that the connected client has.
+    def stickers(self) -> List[GuildSticker]:
+        """List[:class:`.GuildSticker`]: The stickers that the connected client has.
 
         .. versionadded:: 2.0
         """
@@ -396,8 +386,8 @@ class Client:
         return utils.SequenceProxy(self._connection._messages or [])
 
     @property
-    def private_channels(self) -> Sequence[PrivateChannel]:
-        """Sequence[:class:`.abc.PrivateChannel`]: The private channels that the connected client is participating on.
+    def private_channels(self) -> List[PrivateChannel]:
+        """List[:class:`.abc.PrivateChannel`]: The private channels that the connected client is participating on.
 
         .. note::
 
@@ -630,11 +620,7 @@ class Client:
         if self.loop is _loop:
             await self._async_setup_hook()
 
-        if not isinstance(token, str):
-            raise TypeError(f'expected token to be a str, received {token.__class__!r} instead')
-        token = token.strip()
-
-        data = await self.http.static_login(token)
+        data = await self.http.static_login(token.strip())
         self._connection.user = ClientUser(state=self._connection, data=data)
         self._application = await self.application_info()
         if self._connection.application_id is None:
@@ -686,8 +672,6 @@ class Client:
                 _log.info('Got a request to %s the websocket.', e.op)
                 self.dispatch('disconnect')
                 ws_params.update(sequence=self.ws.sequence, resume=e.resume, session=self.ws.session_id)
-                if e.resume:
-                    ws_params['gateway'] = self.ws.gateway
                 continue
             except (
                 OSError,
@@ -711,13 +695,7 @@ class Client:
 
                 # If we get connection reset by peer then try to RESUME
                 if isinstance(exc, OSError) and exc.errno in (54, 10054):
-                    ws_params.update(
-                        sequence=self.ws.sequence,
-                        gateway=self.ws.gateway,
-                        initial=False,
-                        resume=True,
-                        session=self.ws.session_id,
-                    )
+                    ws_params.update(sequence=self.ws.sequence, initial=False, resume=True, session=self.ws.session_id)
                     continue
 
                 # We should only get this when an unhandled close code happens,
@@ -737,12 +715,7 @@ class Client:
                 # Always try to RESUME the connection
                 # If the connection is not RESUME-able then the gateway will invalidate the session.
                 # This is apparently what the official Discord client does.
-                ws_params.update(
-                    sequence=self.ws.sequence,
-                    gateway=self.ws.gateway,
-                    resume=True,
-                    session=self.ws.session_id,
-                )
+                ws_params.update(sequence=self.ws.sequence, resume=True, session=self.ws.session_id)
 
     async def close(self) -> None:
         """|coro|
@@ -754,7 +727,12 @@ class Client:
 
         self._closed = True
 
-        await self._connection.close()
+        for voice in self.voice_clients:
+            try:
+                await voice.disconnect(force=True)
+            except Exception:
+                # if an error happens during disconnects, disregard it.
+                pass
 
         if self.ws is not None and self.ws.open:
             await self.ws.close(code=1000)
@@ -1454,7 +1432,7 @@ class Client:
             The guild with the guild data parsed.
         """
 
-        async def _before_strategy(retrieve: int, before: Optional[Snowflake], limit: Optional[int]):
+        async def _before_strategy(retrieve, before, limit):
             before_id = before.id if before else None
             data = await self.http.get_guilds(retrieve, before=before_id)
 
@@ -1466,7 +1444,7 @@ class Client:
 
             return data, before, limit
 
-        async def _after_strategy(retrieve: int, after: Optional[Snowflake], limit: Optional[int]):
+        async def _after_strategy(retrieve, after, limit):
             after_id = after.id if after else None
             data = await self.http.get_guilds(retrieve, after=after_id)
 
@@ -1902,8 +1880,8 @@ class Client:
         else:
             # the factory can't be a DMChannel or GroupChannel here
             guild_id = int(data['guild_id'])  # type: ignore
-            guild = self._connection._get_or_create_unavailable_guild(guild_id)
-            # the factory should be a GuildChannel or Thread
+            guild = self.get_guild(guild_id) or Object(id=guild_id)
+            # GuildChannels expect a Guild, we may be passing an Object
             channel = factory(guild=guild, state=self._connection, data=data)  # type: ignore
 
         return channel
